@@ -50,18 +50,19 @@ class BuildCurried args r fn | args r -> fn where
 buildCurried :: forall args r fn. BuildCurried args r fn => (args -> IO r) -> fn
 buildCurried = buildCurriedImpl
 
-instance (WrapParam a, fn ~ (a -> r)) => BuildCurried (Param a) r fn where
-  buildCurriedImpl f a = perform (f (wrap a))
+instance (ToParamArg a, Normalize a ~ Param a, fn ~ (a -> r)) => BuildCurried (Param a) r fn where
+  buildCurriedImpl f a = perform (f (toParamArg a))
 
 instance
   ( BuildCurried rest r fn
-  , WrapParam a
+  , ToParamArg a
+  , Normalize a ~ Param a
   , fn' ~ (a -> fn)
   ) =>
   BuildCurried (Param a :> rest) r fn'
   where
   buildCurriedImpl input a =
-    buildCurriedImpl @rest @r @fn (input . (\rest -> wrap a :> rest))
+    buildCurriedImpl @rest @r @fn (input . (\rest -> toParamArg a :> rest))
 
 -- | Class for building a curried pure function without relying on IO.
 class BuildCurriedPure args r fn | args r -> fn where
@@ -71,18 +72,19 @@ class BuildCurriedPure args r fn | args r -> fn where
 buildCurriedPure :: forall args r fn. BuildCurriedPure args r fn => (args -> r) -> fn
 buildCurriedPure = buildCurriedPureImpl
 
-instance (WrapParam a, fn ~ (a -> r)) => BuildCurriedPure (Param a) r fn where
-  buildCurriedPureImpl f a = f (wrap a)
+instance (ToParamArg a, Normalize a ~ Param a, fn ~ (a -> r)) => BuildCurriedPure (Param a) r fn where
+  buildCurriedPureImpl f a = f (toParamArg a)
 
 instance
   ( BuildCurriedPure rest r fn
-  , WrapParam a
+  , ToParamArg a
+  , Normalize a ~ Param a
   , fn' ~ (a -> fn)
   ) =>
   BuildCurriedPure (Param a :> rest) r fn'
   where
   buildCurriedPureImpl input a =
-    buildCurriedPureImpl @rest @r @fn (input . (\rest -> wrap a :> rest))
+    buildCurriedPureImpl @rest @r @fn (input . (\rest -> toParamArg a :> rest))
 
 -- | Class for building a curried function whose result stays in IO.
 class BuildCurriedIO args r fn | args r -> fn where
@@ -92,18 +94,19 @@ class BuildCurriedIO args r fn | args r -> fn where
 buildCurriedIO :: forall args r fn. BuildCurriedIO args r fn => (args -> IO r) -> fn
 buildCurriedIO = buildCurriedIOImpl
 
-instance (WrapParam a, fn ~ (a -> IO r)) => BuildCurriedIO (Param a) r fn where
-  buildCurriedIOImpl f a = f (wrap a)
+instance (ToParamArg a, Normalize a ~ Param a, fn ~ (a -> IO r)) => BuildCurriedIO (Param a) r fn where
+  buildCurriedIOImpl f a = f (toParamArg a)
 
 instance
   ( BuildCurriedIO rest r fn
-  , WrapParam a
+  , ToParamArg a
+  , Normalize a ~ Param a
   , fn' ~ (a -> fn)
   ) =>
   BuildCurriedIO (Param a :> rest) r fn'
   where
   buildCurriedIOImpl input a =
-    buildCurriedIOImpl @rest @r @fn (input . (\rest -> wrap a :> rest))
+    buildCurriedIOImpl @rest @r @fn (input . (\rest -> toParamArg a :> rest))
 
 -- | Class for creating a stub corresponding to the parameter description.
 class MockBuilder params fn verifyParams | params -> fn, params -> verifyParams where
@@ -341,7 +344,7 @@ type ParamConstraints params args r =
   , ProjectionReturn params
   , ArgsOf params ~ args
   , ReturnOf params ~ Param r
-  , Eq args
+  , EqParams args
   , Show args
   )
 
@@ -349,13 +352,13 @@ extractReturnValue :: ParamConstraints params args r => Maybe MockName -> params
 extractReturnValue name params inputParams = do
   validateOnly name (projArgs params) inputParams `seq` returnValue params
 
-validateOnly :: (Eq a, Show a) => Maybe MockName -> a -> a -> ()
+validateOnly :: (EqParams a, Show a) => Maybe MockName -> a -> a -> ()
 validateOnly name expected actual = do
   validateParamsPure name expected actual
 
-validateParamsPure :: (Eq a, Show a) => Maybe MockName -> a -> a -> ()
+validateParamsPure :: (EqParams a, Show a) => Maybe MockName -> a -> a -> ()
 validateParamsPure name expected actual =
-  if expected == actual
+  if expected `eqParams` actual
     then ()
     else errorWithoutStackTrace $ message name expected actual
 
@@ -379,7 +382,7 @@ findReturnValuePure ::
   args ->
   Maybe r
 findReturnValuePure paramsList inputParams = do
-  let matchedParams = filter (\params -> projArgs params == inputParams) paramsList
+  let matchedParams = filter (\params -> projArgs params `eqParams` inputParams) paramsList
   case matchedParams of
     [] -> Nothing
     _ -> do
@@ -408,7 +411,7 @@ singleInvocationStep ::
   InvocationStep args r
 singleInvocationStep name params inputParams record@InvocationRecord {invocations, invocationCounts} = do
   let expected = projArgs params
-  if expected == inputParams
+  if expected `eqParams` inputParams
     then
       (InvocationRecord {
         invocations = invocations ++ [inputParams]
@@ -424,7 +427,7 @@ casesInvocationStep ::
   InvocationStep args r
 casesInvocationStep name paramsList inputParams InvocationRecord {invocations, invocationCounts} = do
   let newInvocations = invocations ++ [inputParams]
-      matchedParams = filter (\params -> projArgs params == inputParams) paramsList
+      matchedParams = filter (\params -> projArgs params `eqParams` inputParams) paramsList
       expectedArgs = projArgs <$> paramsList
     in case matchedParams of
         [] ->
@@ -432,9 +435,9 @@ casesInvocationStep name paramsList inputParams InvocationRecord {invocations, i
             Left (messageForMultiMock name expectedArgs inputParams)
           )
         _ ->
-          let calledCount = fromMaybe 0 (lookup inputParams invocationCounts)
+          let calledCount = fromMaybe 0 (lookupEqParams inputParams invocationCounts)
               index = min calledCount (length matchedParams - 1)
-              nextCounter = incrementCount inputParams invocationCounts
+              nextCounter = incrementCountEqParams inputParams invocationCounts
               nextRecord =
                 InvocationRecord
                   { invocations = newInvocations,
@@ -446,4 +449,16 @@ casesInvocationStep name paramsList inputParams InvocationRecord {invocations, i
                     Left (messageForMultiMock name expectedArgs inputParams)
                   )
                 Just selected ->
-                  (nextRecord, Right (returnValue selected))
\ No newline at end of file
+                  (nextRecord, Right (returnValue selected))
+
+lookupEqParams :: EqParams k => k -> [(k, v)] -> Maybe v
+lookupEqParams _ [] = Nothing
+lookupEqParams k ((x,y):xs)
+  | eqParams k x = Just y
+  | otherwise    = lookupEqParams k xs
+
+incrementCountEqParams :: (EqParams k, Num v) => k -> [(k, v)] -> [(k, v)]
+incrementCountEqParams k [] = [(k, 1)]
+incrementCountEqParams k ((x,y):xs)
+  | eqParams k x = (x, y + 1) : xs
+  | otherwise    = (x, y) : incrementCountEqParams k xs
\ No newline at end of file
